<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name/>
    <message>
        <source>Delete</source>
        <translation type="vanished">Удалить</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="vanished">На весь экран</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="vanished">Слайд-шоу</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Экспорт</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">Копировать</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="vanished">Добавить в избранное</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="vanished">Повернуть по часовой стрелке</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="vanished">Повернуть против часовой стрелки</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="vanished">Установить в качестве обоев</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="vanished">Отображать в файловом менеджере</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="vanished">Информация о фотографии</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation type="vanished">Информация о  видео</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="vanished">Восстановить</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Unnamed</source>
        <translation>Безымянный</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Создать</translation>
    </message>
    <message>
        <source>New Album</source>
        <translation>Новый альбом</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this album?</source>
        <translation>Вы уверены, что хотите удалить этот альбом?</translation>
    </message>
</context>
<context>
    <name>AlbumLeftTabItem</name>
    <message>
        <source>Trash</source>
        <translation>Корзина</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Избранные</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Импортировать</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <source>Trash</source>
        <translation>Корзина</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Избранные</translation>
    </message>
    <message>
        <source>Or drag photos here</source>
        <translation>Или перетащите фотографии сюда</translation>
    </message>
    <message>
        <source>Import All</source>
        <translation>Импортировать всё</translation>
    </message>
    <message>
        <source>Import to:</source>
        <translation>Импортировать в:</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Импортировать</translation>
    </message>
    <message>
        <source>System Disk</source>
        <translation>Системный диск</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Галерея</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Диск занят, в данный момент невозможно извлечь</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Новый альбом</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Игнорировать</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Загрузка...</translation>
    </message>
    <message>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Заменить</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Экспорт</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Изображения</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Документы</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Загрузки</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Рабочий стол</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Видео</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Музыка</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Имя:</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Сохранить в:</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Формат:</translation>
    </message>
    <message>
        <source>Quality:</source>
        <translation>Качество:</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>gif</source>
        <translation>gif</translation>
    </message>
    <message>
        <source>Select other directories</source>
        <translation>Выбрать другие папки</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>File name cannot be empty</source>
        <translation>Имя файла не может быть пустым</translation>
    </message>
    <message>
        <source>already exists. Do you want to replace it?</source>
        <translation>уже существует. Вы хотите его заменить?</translation>
    </message>
</context>
<context>
    <name>DBManager</name>
    <message>
        <source>Screen Capture</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Camera</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Draw</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>(copy)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Drive</source>
        <translation>%1 Диск</translation>
    </message>
    <message>
        <source>Blank %1 Disc</source>
        <translation>Пустой % 1 Диск</translation>
    </message>
    <message>
        <source>%1 Encrypted</source>
        <translation>% 1 Зашифровано</translation>
    </message>
    <message>
        <source>%1 Volume</source>
        <translation>%1 Том</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Export Photos</source>
        <translation>Экспорт Фотографий</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>ImageEngineApi</name>
    <message>
        <source>Deleting...</source>
        <translation>Удаление...</translation>
    </message>
    <message>
        <source>Restoring...</source>
        <translation>Восстановление...</translation>
    </message>
</context>
<context>
    <name>ImgDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this photo from the album?</source>
        <translation type="vanished">Вы уверены, что хотите удалить эту фотографию из альбома?</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n photos from albums?</source>
        <translation type="vanished"><numerusform>Вы уверены, что хотите удалить %1 фото из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %1 фото из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %1 фото из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %1 фото из альбомов?</numerusform></translation>
    </message>
    <message>
        <source>Are you sure you want to delete this video from the album?</source>
        <translation type="vanished">Вы уверены, что хотите удалить это видео из альбома?</translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n videos from albums?</source>
        <translation type="vanished"><numerusform>Вы уверены, что хотите удалить %n видео из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %n видео из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %n видео из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %n видео из альбомов?</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>Are you sure you want to delete %n items from albums?</source>
        <translation type="vanished"><numerusform>Вы уверены, что хотите удалить %n элемент из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %n элементов из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %n элементов из альбомов?</numerusform><numerusform>Вы уверены, что хотите удалить %n элементов из альбомов?</numerusform></translation>
    </message>
    <message>
        <source>Are you sure you want to permanently delete this file?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You cannot restore it any longer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to permanently delete %1 files?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You cannot restore them any longer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to delete this file locally?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You can restore it in the trash</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to delete %1 files locally?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You can restore them in the trash</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ImgInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Основная информация</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Подробные сведения</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <source>Import</source>
        <translation>Импортировать</translation>
    </message>
    <message>
        <source>1 photo</source>
        <translation>1 фото</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 видео</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation><numerusform>%n фото</numerusform><numerusform>%n фото</numerusform><numerusform>%n фото</numerusform><numerusform>%n фото</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation><numerusform>%n видео</numerusform><numerusform>%n видео</numerusform><numerusform>%n видео</numerusform><numerusform>%n видео</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation><numerusform>%n элемент</numerusform><numerusform>%n элементов</numerusform><numerusform>%n элементов</numerusform><numerusform>%n элементов</numerusform></translation>
    </message>
</context>
<context>
    <name>ImportView</name>
    <message>
        <source>Import Photos and Videos</source>
        <translation>Импорт фото и видео</translation>
    </message>
    <message>
        <source>Or drag them here</source>
        <translation>Или перетащите их сюда</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation>Все фото и видео</translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation>Ни фото, ни видео не найдено</translation>
    </message>
</context>
<context>
    <name>LeftListView</name>
    <message>
        <source>Slide show</source>
        <translation>Слайд-шоу</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Экспорт</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Устройство</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Галерея</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Альбомы</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Новый альбом</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Album is a fashion manager for viewing and organizing photos and videos.</source>
        <translation>Альбом - это модный менеджер для просмотра и организации фото и видео.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Photos</source>
        <translation>Фотографии</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>На весь экран</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Отображение в файловом менеджере</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Слайд-шоу</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Установить в качестве обоев</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Повернуть по часовой стрелке</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Повернуть против часовой стрелки</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Предыдущий</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Следующий</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Добавить в избранное</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Удалить из избранного</translation>
    </message>
    <message>
        <source>Rename album</source>
        <translation>Переименовать альбом</translation>
    </message>
    <message>
        <source>Album “%1” removed</source>
        <translation>Альбом “%1” удален</translation>
    </message>
    <message>
        <source>Successfully added to “%1”</source>
        <translation>Успешно добавлено в “%1”</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>Импорт успешно завершен</translation>
    </message>
    <message>
        <source>Import failed</source>
        <translation>Не удалось импортировать</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Не удалось экспортировать</translation>
    </message>
    <message>
        <source>Export successful</source>
        <translation>Экспорт успешно завершен</translation>
    </message>
    <message>
        <source>All Photos</source>
        <translation>Все Фотографии</translation>
    </message>
    <message>
        <source>Timelines</source>
        <translation>Временная шкала</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Альбомы</translation>
    </message>
    <message>
        <source>Exit fullscreen/slideshow</source>
        <translation>Выход из полноэкранного режиме / слайд-шоу</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Отображать ярлыки</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Показать</translation>
    </message>
    <message>
        <source>Select all</source>
        <translation>Выбрать все</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Приблизить</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Уменьшить</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Новый альбом</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Листать вверх</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Листать вниз</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Импортирование...</translation>
    </message>
    <message>
        <source>All photos and videos</source>
        <translation>Все фото и видео</translation>
    </message>
    <message>
        <source>Import Photos and Videos</source>
        <translation>Импорт фото и видео</translation>
    </message>
    <message>
        <source>No photos or videos found</source>
        <translation>Ни фото, ни видео не найдено</translation>
    </message>
    <message>
        <source>Export photos</source>
        <translation>Экспорт фото</translation>
    </message>
    <message>
        <source>Import photos/videos</source>
        <translation>Импорт фото/видео</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Photo/Video info</source>
        <translation>Информация о фото/видео</translation>
    </message>
    <message>
        <source>Import photos and videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Import folders</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Import interrupted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot add this path, please try another one</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The path already exists</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to restore %1 files: file name too long</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Flash</source>
        <translation>Вспышка</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Размер файла</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Размеры</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Дата создания</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Дата изменения</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Режим экспозиции</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Программа экспозиции</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Время экспозиции</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Диафрагма</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Фокусное расстояние</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Максимальная Диафрагма</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Режим измерения</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Баланс белого</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Компенсация вспышки</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Модель камеры</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Модель объектива</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Цветовое пространство</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Тег</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <source>No results</source>
        <translation>Нет результатов</translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <source>System Disk</source>
        <translation>Системный диск</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Select</source>
        <translation>Выбрать</translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation>Отменить выбор</translation>
    </message>
    <message>
        <source>%1/%2/%3</source>
        <translation>%1/%2/%3</translation>
    </message>
    <message>
        <source>Imported on</source>
        <translation>Импортировано на</translation>
    </message>
    <message>
        <source> %1-%2-%3 %4</source>
        <translation> %1-%2-%3 %4</translation>
    </message>
    <message>
        <source>Imported on </source>
        <translation>Импортировано на</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Выбрать всё</translation>
    </message>
    <message>
        <source>Unselect All</source>
        <translation>Снять выделение</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Восстановить</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Всё</translation>
    </message>
    <message>
        <source>Photos</source>
        <translation>Фотографии</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Видео</translation>
    </message>
    <message>
        <source>No results</source>
        <translation>Нет результатов</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Добавить в избранное</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Повернуть против часовой стрелки</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Повернуть по часовой стрелке</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Импортирование...</translation>
    </message>
    <message>
        <source>%1/%2 items imported</source>
        <translation>%1/%2 элементов импортирован (ы)</translation>
    </message>
    <message>
        <source>%1/%2 items deleted</source>
        <translation>%1/%2 элементов удален (ы)</translation>
    </message>
    <message>
        <source>%1 items imported, %2 items failed</source>
        <translation>%1 элемент (ов) импортирован (о), %2 элемент (ов) не удалось импортировать</translation>
    </message>
    <message>
        <source>1 photo selected</source>
        <translation>1 фото выбрано</translation>
    </message>
    <message>
        <source>1 video selected</source>
        <translation>1 видео выбрано</translation>
    </message>
    <message>
        <source>The photo/video already exists</source>
        <translation>Фото/видео уже существует</translation>
    </message>
    <message numerus="yes">
        <source>%n photos selected</source>
        <translation><numerusform>%n фото выбрано</numerusform><numerusform>%n фото выбраны</numerusform><numerusform>%n фото выбраны</numerusform><numerusform>%n фото выбраны</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n videos selected</source>
        <translation><numerusform>%n видео выбрано</numerusform><numerusform>%n видео выбраны</numerusform><numerusform>%n видео выбраны</numerusform><numerusform>%n видео выбраны</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n items selected</source>
        <translation><numerusform>%n элемент выбран</numerusform><numerusform>%n элементов выбрано</numerusform><numerusform>%n элементов выбрано</numerusform><numerusform>%n элементов выбрано</numerusform></translation>
    </message>
    <message>
        <source>%1 items imported, %2 items exist already</source>
        <translation>%1 элемент (ов) импортирован (о), %2 элемент (ов) не удалось импортировать</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>No search results</source>
        <translation>Нет результатов поиска</translation>
    </message>
    <message>
        <source>Slide Show</source>
        <translation>Cлайд-шоу</translation>
    </message>
    <message>
        <source>Search results</source>
        <translation>Результаты поиска</translation>
    </message>
    <message>
        <source>1 photo found</source>
        <translation>Найдено 1 фото</translation>
    </message>
    <message numerus="yes">
        <source>%n videos found</source>
        <translation><numerusform>Найдено %n видео</numerusform><numerusform>Найдены %n видео</numerusform><numerusform>Найдены %n видео</numerusform><numerusform>Найдены %n видео</numerusform></translation>
    </message>
    <message>
        <source>1 video found</source>
        <translation>Найдено 1 видео</translation>
    </message>
    <message numerus="yes">
        <source>%n items found</source>
        <translation><numerusform>Найден %n элемент</numerusform><numerusform>Найдено %n элементов</numerusform><numerusform>Найдено %n элементов</numerusform><numerusform>Найдено %n элементов</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n photos found</source>
        <translation><numerusform>Найдено %n фото</numerusform><numerusform>Найдено %n фото</numerusform><numerusform>Найдено %n фото</numerusform><numerusform>Найдено %n фото</numerusform></translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>1 photo</source>
        <translation>1 фото</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 видео</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation><numerusform>%n фото</numerusform><numerusform>%n фото</numerusform><numerusform>%n фото</numerusform><numerusform>%n фото</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation><numerusform>%n видео</numerusform><numerusform>%n видео</numerusform><numerusform>%n видео</numerusform><numerusform>%n видео</numerusform></translation>
    </message>
    <message>
        <source>Importing: %1</source>
        <translation>Импортировано: %1</translation>
    </message>
    <message>
        <source>Exporting: %1</source>
        <translation>Экспортировано: %1</translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <source>View</source>
        <translation>Показать</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>На весь экран</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Экспорт</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Избранное</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Удалить из избранного</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Повернуть по часовой стрелке</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Повернуть против часовой стрелки</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Отображать в файловом менеджере</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Установить в качестве обоев</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Слайд-шоу</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>Информация о фотографии</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Добавить в альбом</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Удалить из альбома</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Восстановить</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Новый альбом</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Печать</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation>Информация о  видео</translation>
    </message>
    <message>
        <source>days</source>
        <translation>дней</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <source>1 photo</source>
        <translation>1 фото</translation>
    </message>
    <message>
        <source>1 video</source>
        <translation>1 видео</translation>
    </message>
    <message numerus="yes">
        <source>%n photos</source>
        <translation><numerusform>%n фото</numerusform><numerusform>%n фото</numerusform><numerusform>%n фото</numerusform><numerusform>%n фото</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n videos</source>
        <translation><numerusform>%n видео</numerusform><numerusform>%n видео</numerusform><numerusform>%n видео</numerusform><numerusform>%n видео</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n items</source>
        <translation><numerusform>%n элемент</numerusform><numerusform>%n элементов</numerusform><numerusform>%n элементов</numerusform><numerusform>%n элементов</numerusform></translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <source>Basic info</source>
        <translation>Основная информация</translation>
    </message>
    <message>
        <source>Codec info</source>
        <translation>Информация о кодеке</translation>
    </message>
    <message>
        <source>Audio info</source>
        <translation>Информация об аудио</translation>
    </message>
    <message>
        <source>Video CodecID</source>
        <translation>Видео КодекИД</translation>
    </message>
    <message>
        <source>Video CodeRate</source>
        <translation>Битрейт</translation>
    </message>
    <message>
        <source>FPS</source>
        <translation>Кадров в секунду</translation>
    </message>
    <message>
        <source>Proportion</source>
        <translation>Соотношение сторон</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Разрешение</translation>
    </message>
    <message>
        <source>Audio CodecID</source>
        <translation>Аудио КодекИД</translation>
    </message>
    <message>
        <source>Audio CodeRate</source>
        <translation>Битрейт</translation>
    </message>
    <message>
        <source>Audio digit</source>
        <translation>Цифровое аудио</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>Каналы</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Канал</translation>
    </message>
    <message>
        <source>Sampling</source>
        <translation>Сэмплирование</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Дата изменения</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Размер файла</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Продолжительность</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Путь</translation>
    </message>
    <message>
        <source>Video info</source>
        <translation>Информация о  видео</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Дата создания</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>